@@ -2,6 +2,8 @@
 import os.path as osp
 import logging, subprocess, os, glob, shutil
 
+DEFAULT_LOGGING_LEVEL = logging.WARNING
+
 def setup_logger(name='seutils'):
     if name in logging.Logger.manager.loggerDict:
         logger = logging.getLogger(name)
@@ -17,14 +19,14 @@ def setup_logger(name='seutils'):
         handler = logging.StreamHandler()
         handler.setFormatter(fmt)
         logger = logging.getLogger(name)
-        logger.setLevel(logging.WARNING)
+        logger.setLevel(DEFAULT_LOGGING_LEVEL)
         logger.addHandler(handler)
     return logger
 logger = setup_logger()
 
 def debug(flag=True):
     """Sets the logger level to debug (for True) or warning (for False)"""
-    logger.setLevel(logging.DEBUG if flag else logging.WARNING)
+    logger.setLevel(logging.DEBUG if flag else DEFAULT_LOGGING_LEVEL)
 
 def is_string(string):
     """
@@ -320,7 +322,7 @@ def ls_root(paths):
     return root_files
 
 
-def hadd(src, dst):
+def hadd(src, dst, dry=False):
     """
     Calls `ls_root` on `src` in order to be able to pass directories, then hadds.
     Needs ROOT env to be callable.
@@ -329,7 +331,11 @@ def hadd(src, dst):
     if not len(root_files):
         raise RuntimeError('src {0} yielded 0 root files'.format(src))
     cmd = ['hadd', dst] + root_files
+    if dry:
+        logger.warning('hadd command: ' + ' '.join(cmd))
+        return
     try:
+        debug(True)
         run_command(cmd)
     except OSError as e:
         if e.errno == 2:
@@ -337,7 +343,8 @@ def hadd(src, dst):
         else:
             # Something else went wrong while trying to run `hadd`
             raise
-
+    finally:
+        debug(False)
 
 # _______________________________________________________
 # Command line helpers
